#!/bin/sh
# IBM Confidential OCO Source Material
# 5630-A36 (C) COPYRIGHT International Business Machines Corp. 2000, 2002
# The source code for this program is not published or otherwise divested
# of its trade secrets, irrespective of what has been deposited with the
# U.S. Copyright Office.

#####################################################
#                                                   #
# J2C migration tool.                               #
#                                                   #  
# Version 1.0                                       #
#                                                   #
#####################################################

if [ $# -gt 1 ]
then
	# Set the classpath for the tool.
	while [ $# -gt 1 ] && [ "$inputfile" = "" ]
		do 
			case "$1" in 
				-f )
					inputfile=$2 ;;
				-w ) 
					wsdlsource=$2 ;;
				-p ) 
					project=$2 ;;
				-d ) 
					WORKSPACE=$2 ;;
				-t ) 
					type=$2 ;;
				-s ) 
					summary=$2 ;;
				-o )  
					option=$2 ;;
			esac
	
		shift 2
	done
	
	if [ "$ECLIPSE_ROOT" = "" ]
	then
		ECLIPSE_ROOT="/opt/IBM/RXD"
	fi

	if [ "$JDK_HOME" = "" ]
	then
		JDK_HOME="$ECLIPSE_ROOT/jdk/jre/bin"
	fi


	if [ "$WORKSPACE" = "" ]
	then
		WORKSPACE="$ECLIPSE_ROOT/workspace/Migration"
	fi
	
      if [ "$RARVARPATH" = "" ]
	then
		RARVARPATH="$ECLIPSE_ROOT/ResourceAdapters"
	fi

      if [ "$WASRUNTIME" = "" ]
	then
		WASRUNTIME="$ECLIPSE_ROOT/runtimes"
	fi

	
	if [ "$inputfile" = "" ]
	then
		echo ===============================================
		echo Displaying options entered from command line
		echo ===============================================
		echo option: $option
		echo 
		echo type: $type
		echo 
		echo project: $project
		echo 
		echo summary: $summary
		echo 
		echo wsdlsource: $wsdlsource 
		echo 
		echo ================================================
		echo
		echo eclipse_root: $ECLIPSE_ROOT
		echo JDK_HOME: $JDK_HOME
		echo workspace: $WORKSPACE
		echo was.runtime:$WASRUNTIME 
        echo rarsPathVar:$RARVARPATH
        echo 
		echo ================================================
		
		 
		
		if [ "$project" != "" ]
		then
			OUTPUT="-output=$project"
		fi

		if [ "$summary" != "" ]
		then
			REPORT="-report=$summary"
		fi

		if [ "$wsdlsource" != "" ]
		then
			WSDL="-wsdl=$wsdlsource" 
		fi

		if [ "$option" != "" ]
		then
			OPTION="-$option"
		fi

		if [ "$type" != "" ]
		then
			TYPE="-$type"
		fi


		echo 
		echo Invoking the command line migration Tool...
		echo 
		
		"$JDK_HOME/java" -Xj9 -Dwas.runtime="$WASRUNTIME" -DrarsPathVar="$RARVARPATH" -cp "$ECLIPSE_ROOT/startup.jar" org.eclipse.core.launcher.Main -os linux -ws gtk -clean -data "$WORKSPACE" -application com.ibm.j2c.migration.wsadie.J2CMigration $WSDL $OUTPUT $TYPE $REPORT $OPTION
	
	else
		echo
		echo eclipse_root: $ECLIPSE_ROOT
		echo JDK_HOME:$JDK_HOME
		echo workspace: $WORKSPACE
		echo  
 	      echo was.runtime:$WASRUNTIME 
            echo rarsPathVar:$RARVARPATH
            echo 

		FILE="-file=$inputfile"
		
		echo
		echo inputfile: $inputfile
		echo $FILE
		echo
		
		# -clean option only for internal development to pickup fixes by migration.jar plugin.
		# -clean will take a long time , normally do not use -clean
		# ECHO. "$JDK_HOME/java" -Xj9  -Dwas.runtime="$WASRUNTIME" -DrarsPathVar="$RARVARPATH" -cp "$ECLIPSE_ROOT/startup.jar" org.eclipse.core.launcher.Main -data "$WORKSPACE" -application com.ibm.j2c.migration.wsadie.J2CMigration $FILE 
		#
		echo Invoking the command line migration Tool...
		echo

		"$JDK_HOME/java" -Xj9 -Dwas.runtime="$WASRUNTIME" -DrarsPathVar="$RARVARPATH"  -cp "$ECLIPSE_ROOT/startup.jar" org.eclipse.core.launcher.Main -os linux -ws gtk -clean -data "$WORKSPACE" -application com.ibm.j2c.migration.wsadie.J2CMigration $FILE 
	fi

else
	echo You should provide at least one input. 

	echo ===========================================================================================
	echo You need to set the eclipse_root and JDK_HOME inside the J2CMigration.bat first
	echo 
      echo ECLIPSE_ROOT is the directory where eclipse.exe and eclipse.ini is located
      echo
      echo    The default path is "/opt/IBM/RAD"  for RAD
      echo    The default path is "/opt/IBM/RSA"  for RSA
      echo  
      echo 
      echo JDK_HOME  is where your java.exe is located
      echo 
      echo     The default path should be $ECLIPSE_ROOT/jre/bin 
      echo 
      echo RARVARPATH is the directory where the resource adapters are located
      echo    
      echo     The default value is $ECLIPSE_ROOT/ResourceAdapters and there is a
      echo     variable rarsPathVar defined in $ECLIPSE_ROOT/eclipse.ini
      echo
      echo
      echo WASRUNTIME is the directory of where the WAS runtime stub is located
      echo
      echo     The default value is $ECLIPSE_ROOT/runtimes
      echo     There is a variable was.runtime defined in $ECLIPSE_ROOT/configuration/config.ini
      echo 
      echo
	echo You can locate the default values of rarsPathVar and was.runtime in  $ECLIPSE_ROOT/configuration/config.ini
	echo
	echo If they are not correct, go to the J2CMigraion.sh file to change it
	echo
	echo
	echo
	echo ================================================echo
	echo
	echo Usage:      J2CMigration.sh 
	echo             -w wsdlsource -d workspace [-p project] [-t type] [-o option] [-s summary] 
	echo
	echo
	echo workspace:  The workspace of where output is generated 
      echo             The default value is set to $ECLIPSE_ROOT/workspace/Migration
	echo
	echo wsdlsource: The full path of the service WSDL file
	echo             or the full path of the folder that contains one or more
	echo             services WSDL files.
	echo
	echo project:    The name of the project where the migrated artifacts will be generated.
	echo             Do not include a path, just a Name for the project.  
	echo             You can specify web, Java, or EJB project to be created.
	echo             If no project is specified, a default Java project will be created.
	echo             If you do not specify the -p option, then the migrated artifacts
	echo             will be generated to the project specified in the service WSDL file.
	echo
	echo type:       WEB or EJB or JAVA
	echo             Project type of the output project
	echo
	echo option:     databindingonly or commandbean
	echo             databindingonly: Specify this option if you want only data binding 
	echo                              beans to be generated during migration.    
	echo             commandbean:     Specify this option if you want 
	echo                              a command bean to be generated. 
	echo             If you specify databindingonly, 
	echo             the commandbean option will be ignored.
	echo
	echo summary:    The name of migration summary "("without .xml")".
	echo             If none is specified, the default summary file will be 
	echo             j2cmigration_timestamp.xml 
	echo             If the summary file say summary.xml already exists,
	echo             we will write the summary to the summary_timestamp.xml.
	echo
	echo migrationinputfile: The migration file which contains the above options to be
	echo                     passed into the command line migration tool
	echo                     This method is useful when you command line options are too 
	echo                     long. 
	echo 
	echo 
	echo 
	echo =================================================================================
	echo 
	echo Example: 
	echo 
	echo  
	echo J2CMigration.bat -d "/root/myworkspace" -w "/root/mywsdl.wsdl" -p "OutputProject"
	echo J2CMigration.bat  -w "/root/mywsdl.wsdl" -p "OutputProject" -s "MigrationReport"
	echo J2CMigration.bat  -w "/root/mywsdlFolder" -p "OutputProject" -s "MigrationReport"
	echo J2CMigration.bat -w "/root/myfolder" -o databindingonly  
	echo J2CMigration.bat -w "/root/myfolder" -o commandbean -t EJB  
	echo J2CMigration.bat -f "/root/mymigrationinputs"
	echo 
fi
